package lebrijo.school.dao;

import java.util.List;
import java.util.Map;

import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;

import lebrijo.school.model.Registry;

import org.springframework.stereotype.Repository;

/**
 * The DAO class for the Registry entity.
 */
@Repository
public class RegistryJPADao implements IRegistryDao {
    @PersistenceContext
    private EntityManager em;

	public RegistryJPADao() {
		super();
	}
	/**
	 * Return the persistent entities returned from a named query.
	 */
	public List findByNamedQuery(String queryName) {
		Query queryObject = em.createNamedQuery(queryName);
		return queryObject.getResultList();
	}
	/**
	 * Return the persistent entities returned from a named query with named parameters.
	 */
	public List findByNamedQuery(String queryName, String[] paramNames, Object[] paramValues) {
		if (paramNames.length != paramValues.length) {
			throw new IllegalArgumentException();
		}
		Map<String, Object> params = new java.util.HashMap<String, Object>(paramNames.length);
		for (int i = 0; i < paramNames.length; ++i) {
			params.put(paramNames[i], paramValues[i]);
		}
		
		Query queryObject = em.createNamedQuery(queryName);
		if (params != null) {
			for (Map.Entry<String, ?> entry : params.entrySet()) {
				queryObject.setParameter(entry.getKey(), entry.getValue());
			}
		}
		return queryObject.getResultList();

	}
	/**
	 * Find an entity by its id (primary key).
	 * @return The found entity instance or null if the entity does not exist.
	 */
	public Registry findRegistryById(java.lang.String id) {
		return (Registry)em.find(Registry.class, id);
	}
	/**
	 * Return all persistent instances of the <code>Registry</code> entity.
	 */
	@SuppressWarnings("unchecked")
	public List<Registry> findAllRegistries() {
        try {
    		String jpqlString = "select registry from " + Registry.class.getSimpleName() + " registry";
            Query query = em.createQuery( jpqlString );
            return query.getResultList();
        }
        finally {
            if (em != null) {
                em.close();
            }
        }
	}
	/**
	 * Make the given instance managed and persistent.
	 */
	public void persistRegistry(Registry registry) {
		em.persist(em.merge(registry));
	}
	/**
	 * Remove the given persistent instance.
	 */
	public void removeRegistry(Registry registry) {
		/*In JPA, objects detach automatically when they are serialized or when a persistence context ends.
		 The merge method returns a managed copy of the given detached entity.*/
		em.remove(em.merge(registry));
	}
}