package lebrijo.school.services;

import java.util.List;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import org.springframework.context.ApplicationContext;
import lebrijo.school.model.Registry;
import lebrijo.school.dao.IRegistryDao;

/**
 * The service class for the Registry entity.
 */
@Transactional(propagation=Propagation.REQUIRED)
public class RegistrySpringService implements IRegistryService {
	/**
	 * The dao instance injected by Spring.
	 */
	private IRegistryDao dao;
	/**
	 * The service Spring bean id, used in the applicationContext.xml file.
	 */
	private static final String SERVICE_BEAN_ID = "SchoolCertificatesService";
	
	public RegistrySpringService() {
		super();
	}
	/**
	 * Returns the singleton <code>IRegistryService</code> instance.
	 */
	public static IRegistryService getInstance(ApplicationContext context) {
		return (IRegistryService)context.getBean(SERVICE_BEAN_ID);
	}
	/**
	 * Find an entity by its id (primary key).
	 * @return The found entity instance or null if the entity does not exist.
	 */
	@Transactional(propagation=Propagation.NEVER, readOnly=true)
	public Registry findRegistryById(java.lang.String id) throws Exception {
		try {
			return getDao().findRegistryById(id);
		} catch (RuntimeException e) {
			throw new Exception("findRegistryById failed with the id " + id + ": " + e.getMessage());
		}
	}
	/**
	 * Return all persistent instances of the <code>Registry</code> entity.
	 */
	@Transactional(propagation=Propagation.NEVER, readOnly=true)
	public List<Registry> findAllRegistries() throws Exception {
		try {
			return getDao().findAllRegistries();
		} catch (RuntimeException e) {
			throw new Exception("findAllRegistries failed: " + e.getMessage());
		}
	}

	/**
	 * Make the given instance managed and persistent.
	 */
	public void persistRegistry(Registry registry) throws Exception {
		try {
			getDao().persistRegistry(registry);
		} catch (RuntimeException e) {
			throw new Exception("persistRegistry failed: " + e.getMessage());
		}
	}
	/**
	 * Remove the given persistent instance.
	 */
	public void removeRegistry(Registry registry) throws Exception {
		try {
			getDao().removeRegistry(registry);
		} catch (RuntimeException e) {
			throw new Exception("removeRegistry failed: " + e.getMessage());
		}
	}

	/**
	 * Called by Spring using the injection rules specified in 
	 * the Spring beans file "applicationContext.xml".
	 */
	public void setDao(IRegistryDao dao) {
		this.dao = dao;
	}
	public IRegistryDao getDao() {
		return this.dao;
	}
}